@@ -2,7 +2,7 @@ chkSplinesFormula <- function(spline) {
   splErr <- paste("spline should be a formula of form \"~ spl1D() + ... + ",
                   "spl1D()\", \"~ spl2D()\" or \"~spl3D()\"\n")
   if (!is.null(spline)) {
-    if (!inherits(spline, "formula")) stop(splErr)
+    if (!inherits(spline, "formula")) stop(splErr, call. = FALSE)
     spline <- formula(paste((gsub(pattern = "LMMsolver::",
                                   replacement = "",
                                   as.character(spline))), collapse = ""))
@@ -13,7 +13,7 @@ chkSplinesFormula <- function(spline) {
         length(unlist(splSpec)) != length(labels(terms(spline))) ||
         length(splSpec$spl2D) > 1 ||
         length(splSpec$spl3D) > 1) {
-      stop(splErr)
+      stop(splErr, call. = FALSE)
     }
   }
 }
