@@ -117,7 +117,7 @@ designMatrixPredSplines <- function(object,
 #' @param which An integer, for if there are multiple splxD terms in the model.
 #' Default value is 1.
 #'
-#' @return A data.frame with predictions for the smooth trend on the specified
+#' @returns A data.frame with predictions for the smooth trend on the specified
 #' grid. The standard errors are saved if `deriv` has default value 0.
 #'
 #' @examples
@@ -165,6 +165,10 @@ obtainSmoothTrend <- function(object,
     stop("which should be an integer with value at most the number of fitted",
          "spline components.\n")
   }
+  if (object$family$family == "multinomial") {
+    stop("For multinomial response use predict function.\n")
+  }
+
   splRes <- object$splRes[[which]]
   x <- splRes$x
   ## make the design matrix needed for predictions and corresponding
