@@ -40,14 +40,14 @@ ggplot(data = dat1, aes(x = x, y = y)) +
   theme_bw()
 
 ## ----nonlinearFun-------------------------------------------------------------
-f2 <- function(x) { 0.3 + 0.4*x + 0.2*sin(20*x) }
+g <- function(x) { 0.3 + 0.4*x + 0.2*sin(20*x) }
 
 ## ----simDat2------------------------------------------------------------------
 set.seed(12)
 n <- 150
 x <- seq(0, 1, length = n)
 sigma2e <- 0.04
-y <- f2(x) + rnorm(n, sd = sqrt(sigma2e))
+y <- g(x) + rnorm(n, sd = sqrt(sigma2e))
 dat2 <- data.frame(x, y)
 
 ## ----nonlinearFit-------------------------------------------------------------
@@ -61,7 +61,7 @@ summary(obj2)
 ## ----predict_non--------------------------------------------------------------
 newdat <- data.frame(x = seq(0, 1, length = 300))
 pred2 <- predict(obj2, newdata = newdat, se.fit = TRUE)
-pred2$y_true <- f2(pred2$x)
+pred2$y_true <- g(pred2$x)
 
 ggplot(data = dat2, aes(x = x, y = y)) +
   geom_point(col = "black", size = 1.5) +
@@ -72,34 +72,18 @@ ggplot(data = dat2, aes(x = x, y = y)) +
               alpha=0.2, inherit.aes = FALSE) +
   theme_bw() 
 
-## ----poissonSim---------------------------------------------------------------
-set.seed(1234)
-n <- 150
-x <- seq(0, 1, length=n)
-fun_lambda <- function(x) { 4 + 3*x + 4*sin(7*x) }
-x <- seq(0, 1, length = n)
-y <- rpois(n = n, lambda = fun_lambda(x)) 
-dat3 <- data.frame(x = x, y = y)
+## ----predict_non_derivative---------------------------------------------------
+dg_dx <- function(x) { 0.4 + 4*cos(20*x) }
+pred2_dx <- predict(obj2, newdata = newdat, se.fit = TRUE, deriv="x")
+pred2_dx$y_true <- dg_dx(pred2_dx$x)
 
-## ----Poisson_LMMsolver--------------------------------------------------------
-obj3 <- LMMsolve(fixed = y ~ 1, 
-                spline = ~spl1D(x, nseg = 50), 
-                family = poisson(), 
-                data = dat3)
-summary(obj3)
-
-## ----predict_poisson----------------------------------------------------------
-newdat <- data.frame(x = seq(0, 1, length = 300))
-pred3 <- predict(obj3, newdata = newdat, se.fit = TRUE)
-pred3$y_true <- fun_lambda(pred3$x)
-
-ggplot(data = dat3, aes(x = x, y = y)) +
-  geom_point(col = "black", size = 1.5) +
-  geom_line(data = pred3, aes(y = y_true), color = "red", 
+ggplot(data = pred2_dx) +
+  geom_line(aes(x=x, y = y_true), color = "red", 
             linewidth = 1, linetype ="dashed") +
-  geom_line(data = pred3, aes(y = ypred), color = "blue", linewidth = 1) +
-  geom_ribbon(data= pred3, aes(x=x, ymin = ypred-2*se, ymax = ypred+2*se),
+  geom_line(aes(x = x, y = ypred), color = "blue", linewidth = 1) +
+  geom_ribbon(aes(x=x, ymin = ypred-2*se, ymax = ypred+2*se),
               alpha=0.2, inherit.aes = FALSE) +
+  geom_hline(yintercept=0.0, linetype = "dashed") + ylab('dy/dx') + 
   theme_bw() 
 
 ## ----twoExperiments-----------------------------------------------------------
@@ -113,8 +97,8 @@ sigma2e_B <- 0.10
 
 x1 <- runif(n = nA)
 x2 <- runif(n = nB)
-y1 <- f2(x1) + rnorm(nA, sd = sqrt(sigma2e_A)) + mu_A
-y2 <- f2(x2) + rnorm(nB, sd = sqrt(sigma2e_B)) + mu_B
+y1 <- g(x1) + rnorm(nA, sd = sqrt(sigma2e_A)) + mu_A
+y2 <- g(x2) + rnorm(nB, sd = sqrt(sigma2e_B)) + mu_B
 Experiment <- as.factor(c(rep("A", nA), rep("B", nB)))
 dat4 <- data.frame(x = c(x1, x2), y = c(y1,y2), Experiment = Experiment)
 
@@ -125,7 +109,7 @@ ggplot(dat4, aes(x = Experiment, y = y, fill = Experiment)) +
 
 ## ----twoExpSolve--------------------------------------------------------------
 obj4 <- LMMsolve(fixed= y ~ 1, 
-                 spline = ~spl1D(x, nseg = 50),
+                 spline = ~spl1D(x, nseg = 50, xlim = c(0,1)),
                  random = ~Experiment,
                  residual = ~Experiment,
                  data = dat4)
@@ -136,7 +120,7 @@ summary(obj4)
 ## ----twoExpPredict------------------------------------------------------------
 newdat <- data.frame(x=seq(0, 1, length = 300))
 pred4 <- predict(obj4, newdata = newdat, se.fit = TRUE)
-pred4$y_true <- f2(pred4$x)
+pred4$y_true <- g(pred4$x)
 ggplot(data = dat4, aes(x = x, y = y, colour = Experiment)) +
   geom_point(size = 1.5) +
   geom_line(data = pred4, aes(y = y_true), color="red", 
@@ -280,6 +264,130 @@ Y <- (pred_test$sst - pred_test$ypred)^2
 RMSE <- sqrt(mean(Y))
 round(RMSE, 2)
 
+## ----poissonSim---------------------------------------------------------------
+set.seed(1234)
+n <- 150
+x <- seq(0, 1, length=n)
+fun_lambda <- function(x) { 4 + 3*x + 4*sin(7*x) }
+x <- seq(0, 1, length = n)
+y <- rpois(n = n, lambda = fun_lambda(x)) 
+dat3 <- data.frame(x = x, y = y)
+
+## ----Poisson_LMMsolver--------------------------------------------------------
+obj3 <- LMMsolve(fixed = y ~ 1, 
+                spline = ~spl1D(x, nseg = 50), 
+                family = poisson(), 
+                data = dat3)
+summary(obj3)
+
+## ----predict_poisson----------------------------------------------------------
+newdat <- data.frame(x = seq(0, 1, length = 300))
+pred3 <- predict(obj3, newdata = newdat, se.fit = TRUE)
+pred3$y_true <- fun_lambda(pred3$x)
+
+ggplot(data = dat3, aes(x = x, y = y)) +
+  geom_point(col = "black", size = 1.5) +
+  geom_line(data = pred3, aes(y = y_true), color = "red", 
+            linewidth = 1, linetype ="dashed") +
+  geom_line(data = pred3, aes(y = ypred), color = "blue", linewidth = 1) +
+  geom_ribbon(data= pred3, aes(x=x, ymin = ypred-2*se, ymax = ypred+2*se),
+              alpha=0.2, inherit.aes = FALSE) +
+  theme_bw() 
+
+## ----binomial_sim-------------------------------------------------------------
+set.seed(1234)
+n <- 100
+sz <- 10
+
+fun_prob <- function(x) { 0.5 + 0.4*sin(2*pi*x) }
+
+x <- seq(0, 1, length=n)
+nsucces <- sapply(x, FUN=function(x) {
+                  rbinom(n=1, size = sz, prob = fun_prob(x))
+                })
+dat <- data.frame(x = x, succes = nsucces, 
+                         failure= sz - nsucces)
+head(dat, 5)
+
+## ----binomial_solve-----------------------------------------------------------
+obj3 <- LMMsolve(fixed = cbind(succes, failure) ~ 1,
+                 spline = ~spl1D(x, nseg = 50),
+                 family = binomial(),
+                 data = dat)
+summary(obj3)
+
+## ----binomial_predict---------------------------------------------------------
+newdat <- data.frame(x = seq(0, 1, by=0.01))
+pred3 <- predict(obj3, newdata = newdat, se.fit=TRUE)
+
+## ----binomial_plot------------------------------------------------------------
+pred3$y_true <- fun_prob(pred3$x)
+dat$y <- dat$succes/sz
+
+ggplot(data = dat, aes(x = x, y = y)) +
+  geom_point(col = "black", size = 1.5) +
+  geom_line(data = pred3, aes(y = y_true), color = "red",
+            linewidth = 1, linetype = "dashed") +
+  geom_line(data = pred3, aes(y = ypred), color = "blue", linewidth = 1) +
+  geom_ribbon(data= pred3, aes(x=x, ymin = ypred-2*se, ymax = ypred+2*se),
+              alpha=0.2, inherit.aes = FALSE) +
+  theme_bw()
+
+## ----multinomialmodel---------------------------------------------------------
+k <- 4
+mu <- c(0.1, 0.4, 0.6, 0.9)
+names(mu) <- LETTERS[1:k]
+
+nonlinear <- function(x, mu) {
+  z <- sapply(mu, function(mu) { exp(-8*sin(pi*(x-mu))^2)})
+  # normalize to sum equal to one
+  z <- z/sum(z)
+  return(z)
+}
+
+## ----simMultinomial-----------------------------------------------------------
+x <- runif(n, 0, 1)   
+sz <- 10 
+multiNom <- t(sapply(x, FUN=
+                      function(x) {
+                        rmultinom(n=1, size=sz, prob = nonlinear(x,mu))
+                      } ))
+colnames(multiNom) <- names(mu)
+dat <- data.frame(x, multiNom)
+head(dat, 4)
+
+## ----multinomialfit-----------------------------------------------------------
+obj <- LMMsolve(fixed = cbind(A,B,C,D) ~ 1,
+                spline = ~spl1D(x, nseg = 17, xlim = c(0,1)),
+                data = dat, 
+                family = multinomial())
+summary(obj)
+
+## ----makePredictions----------------------------------------------------------
+sRows <- rowSums(multiNom)
+fr <- multiNom/sRows
+dat_fr <- data.frame(x, fr)
+
+x0 <- seq(0, 1, by = 0.01)
+newdat <- data.frame(x = x0)
+pred <- predict(obj, newdata = newdat)
+head(pred)
+
+## ----makePlot-----------------------------------------------------------------
+library(tidyr)
+colnames(pred) <- c("x", "category", "y")
+prob_true <- t(sapply(X=x0, FUN = function(x) { nonlinear(x, mu)}))
+colnames(prob_true) <- names(mu)
+df_true <- data.frame(x = x0, prob_true)
+prob_true_lf <- df_true %>% gather(key = "category",value="y", A:D)
+dat_fr_lf <- dat_fr %>% gather(key = "category",value="y", A:D)
+p1 <- ggplot(prob_true_lf, aes(x = x, y=y, color = category)) +
+  geom_line(linetype='dashed') +
+  geom_line(data=pred) +
+  geom_point(data=dat_fr_lf)
+p1
+
+
 ## ----oatsdata-----------------------------------------------------------------
 ## Load data.
 data(john.alpha, package = "agridat")
@@ -333,10 +441,12 @@ ggplot(data = APSIMdat, aes(x = das, y = biomass)) +
   theme_bw()
 
 ## ----APSIMDeriv---------------------------------------------------------------
-plotDatDt <- obtainSmoothTrend(obj8, grid = 1000, deriv = 1)
+plotDatDt <- predict(obj8, newdata = newdat, se.fit=TRUE, deriv="das")
 
 ggplot(data = plotDatDt, aes(x = das, y = ypred)) +
-  geom_line(color = "red", linewidth = 1) +
+  geom_line(color = "blue", linewidth = 1) +
+  geom_ribbon(aes(x=das, ymin = ypred-2*se, ymax = ypred+2*se),
+              alpha=0.2, inherit.aes = FALSE) +  
   labs(title = "APSIM growth rate as function of time", 
        x = "days after sowing", y = "growth rate (kg/day)") +
   theme_bw()
