@@ -29,8 +29,9 @@ expect_equal(logLik(mod), 198.972874670165)
 expect_equal(logLik(mod, includeConstant = FALSE), 421.355999705696)
 
 ## Check deviance function.
-expect_equal(deviance(mod), -397.945749340331)
-expect_equal(deviance(mod, includeConstant = FALSE), -842.711999411393)
+expect_equal(deviance(mod), 2.28779421608257)
+expect_equal(deviance(mod,relative=FALSE), -397.945749340331)
+expect_equal(deviance(mod,relative=FALSE, includeConstant = FALSE), -842.711999411393)
 
 ## Check coef function.
 coefMod <- coef(mod)
